]> git.proxmox.com Git - mirror_frr.git/commitdiff
*: spelchek
authorDavid Lamparter <equinox@opensourcerouting.org>
Thu, 25 Oct 2018 18:06:59 +0000 (20:06 +0200)
committerDavid Lamparter <equinox@diac24.net>
Thu, 13 Dec 2018 20:17:45 +0000 (21:17 +0100)
Signed-off-by: David Lamparter <equinox@diac24.net>
45 files changed:
babeld/babel_interface.h
babeld/babel_main.c
bgpd/bgp_attr.c
bgpd/bgp_damp.c
bgpd/bgp_errors.c
bgpd/bgp_evpn.c
bgpd/bgp_evpn_vty.c
bgpd/bgp_fsm.c
bgpd/bgp_packet.c
bgpd/bgp_vty.c
doc/manpages/common-options.rst
doc/manpages/zebra.rst
eigrpd/eigrp_const.h
eigrpd/eigrp_dump.c
eigrpd/eigrp_fsm.c
isisd/isis_spf.c
ldpd/ldp_vty_cmds.c
ldpd/util.c
lib/bfd.c
lib/command.h
lib/lib_errors.c
lib/mpls.h
lib/sockunion.c
m4/ax_sys_weak_alias.m4
ospf6d/ospf6_abr.c
ospf6d/ospf6_area.c
ospf6d/ospf6_zebra.c
ospfd/ospf_ism.c
ospfd/ospf_nsm.c
ospfd/ospf_opaque.c
ospfd/ospf_packet.c
ospfd/ospf_ri.c
ospfd/ospf_te.c
ospfd/ospfd.c
pbrd/pbr_zebra.c
pimd/pim_msdp.c
pimd/pim_upstream.c
ripd/ripd.c
ripngd/ripngd.c
tools/start-stop-daemon.c
zebra/if_sysctl.c
zebra/irdp_packet.c
zebra/kernel_socket.c
zebra/zebra_vty.c
zebra/zebra_vxlan.c

index 17d9bfb9360ddd15345a73690e707e3a8f0fb3dd..d9e2745827067df91a58024c3aeb534c751612b9 100644 (file)
@@ -32,7 +32,7 @@ THE SOFTWARE.
 #define CONFIG_NO 1
 #define CONFIG_YES 2
 
-/* babeld interface informations */
+/* babeld interface information */
 struct babel_interface {
     unsigned short flags;                     /* see below */
     unsigned short cost;
index 31a3fb5b4db04aa0078b374f6693c8e8ad221950..8967202056d3138ff538c4db160fe7b01f91e583 100644 (file)
@@ -385,7 +385,7 @@ show_babel_main_configuration (struct vty *vty)
     vty_out (vty,
             "state file              = %s\n"
             "configuration file      = %s\n"
-            "protocol informations:\n"
+            "protocol information:\n"
             "  multicast address     = %s\n"
             "  port                  = %d\n"
             "vty address             = %s\n"
index 720afe6e098b945c13e9fe43cb288cf8de3a92ab..e15ebf794a9a13737fc41e1d8a0a2a9e4240d7e0 100644 (file)
@@ -1690,7 +1690,7 @@ int bgp_mp_reach_parse(struct bgp_attr_parser_args *args,
                                 * - for consistency in rx processing
                                 *
                                 * The following comment is to signal GCC this intention
-                                * and supress the warning
+                                * and suppress the warning
                                 */
        /* FALLTHRU */
        case BGP_ATTR_NHLEN_IPV4:
@@ -2612,7 +2612,7 @@ bgp_attr_parse_ret_t bgp_attr_parse(struct peer *peer, struct attr *attr,
                        return ret;
                }
 
-               /* If hard error occured immediately return to the caller. */
+               /* If hard error occurred immediately return to the caller. */
                if (ret == BGP_ATTR_PARSE_ERROR) {
                        zlog_warn("%s: Attribute %s, parse error", peer->host,
                                  lookup_msg(attr_str, type, NULL));
index bce6056ded4adaae98f71431e86ebcffd618ccfb..1eded782bb31877d945e19a34132d00d23111e90 100644 (file)
@@ -684,7 +684,7 @@ int bgp_show_dampening_parameters(struct vty *vty, afi_t afi, safi_t safi)
                vty_out(vty, "Suppress penalty: %d\n", damp->suppress_value);
                vty_out(vty, "Max suppress time: %lld min\n",
                        (long long)damp->max_suppress_time / 60);
-               vty_out(vty, "Max supress penalty: %u\n", damp->ceiling);
+               vty_out(vty, "Max suppress penalty: %u\n", damp->ceiling);
                vty_out(vty, "\n");
        } else
                vty_out(vty, "dampening not enabled for %s\n",
index 50dd001b8b773945b2941ad6378da50487f28e26..26af5d4d763703af04305cf23557d9e42e78688f 100644 (file)
@@ -29,43 +29,43 @@ static struct log_ref ferr_bgp_err[] = {
                .code = BGP_ERR_ATTR_FLAG,
                .title = "BGP attribute flag is incorrect",
                .description = "BGP attribute flag is set to the wrong value (Optional/Transitive/Partial)",
-               .suggestion = "Determine the soure of the attribute and determine why the attribute flag has been set incorrectly"
+               .suggestion = "Determine the source of the attribute and determine why the attribute flag has been set incorrectly"
        },
        {
                .code = BGP_ERR_ATTR_LEN,
                .title = "BGP attribute length is incorrect",
                .description = "BGP attribute length is incorrect",
-               .suggestion = "Determine the soure of the attribute and determine why the attribute length has been set incorrectly"
+               .suggestion = "Determine the source of the attribute and determine why the attribute length has been set incorrectly"
        },
        {
                .code = BGP_ERR_ATTR_ORIGIN,
                .title = "BGP attribute origin value invalid",
                .description = "BGP attribute origin value is invalid",
-               .suggestion = "Determine the soure of the attribute and determine why the origin attribute has been set incorrectly"
+               .suggestion = "Determine the source of the attribute and determine why the origin attribute has been set incorrectly"
        },
        {
                .code = BGP_ERR_ATTR_MAL_AS_PATH,
                .title = "BGP as path is invalid",
                .description = "BGP as path has been malformed",
-               .suggestion = "Determine the soure of the update and determine why the as path has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the as path has been set incorrectly"
        },
        {
                .code = BGP_ERR_ATTR_FIRST_AS,
                .title = "BGP as path first as is invalid",
                .description = "BGP update has invalid first as in as path",
-               .suggestion = "Determine the soure of the update and determine why the as path first as value has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the as path first as value has been set incorrectly"
        },
        {
                .code = BGP_ERR_ATTR_PMSI_TYPE,
                .title = "BGP PMSI tunnel attribute type is invalid",
                .description = "BGP update has invalid type for PMSI tunnel",
-               .suggestion = "Determine the soure of the update and determine why the PMSI tunnel attribute type has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the PMSI tunnel attribute type has been set incorrectly"
        },
        {
                .code = BGP_ERR_ATTR_PMSI_LEN,
                .title = "BGP PMSI tunnel attribute length is invalid",
                .description = "BGP update has invalid length for PMSI tunnel",
-               .suggestion = "Determine the soure of the update and determine why the PMSI tunnel attribute length has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the PMSI tunnel attribute length has been set incorrectly"
        },
        {
                .code = BGP_ERR_PEER_GROUP,
@@ -101,7 +101,7 @@ static struct log_ref ferr_bgp_err[] = {
                .code = BGP_ERR_JSON_MEM_ERROR,
                .title = "BGP unable to allocate memory for JSON output",
                .description = "BGP attempted to generate JSON output and was unable to allocate the memory required",
-               .suggestion = "Ensure that the device has adequate memory to suport the required functions"
+               .suggestion = "Ensure that the device has adequate memory to support the required functions"
        },
        {
                .code = BGP_ERR_UPDGRP_ATTR_LEN,
index 9e814516b73dfc31957b280020023ab0c717cac3..7ee920aba8e98e9afb85aad2723dd05479dadaf2 100644 (file)
@@ -1447,7 +1447,7 @@ static int update_evpn_type5_route_entry(struct bgp *bgp_def,
        }
 
        /*
-        * create a new route entry if one doesnt exist.
+        * create a new route entry if one doesn't exist.
         * Otherwise see if route attr has changed
         */
        if (!local_ri) {
@@ -5282,7 +5282,7 @@ int bgp_evpn_local_l3vni_add(vni_t l3vni, vrf_id_t vrf_id, struct ethaddr *rmac,
        }
        as = bgp_def->as;
 
-       /* if the BGP vrf instance doesnt exist - create one */
+       /* if the BGP vrf instance doesn't exist - create one */
        bgp_vrf = bgp_lookup_by_name(vrf_id_to_name(vrf_id));
        if (!bgp_vrf) {
 
index b553cb42a5ac4169e748ae015a6449fcb1ba9c4c..e34dbc25559be1da9ea8b9f1c85a2408e33005fa 100644 (file)
@@ -3953,7 +3953,7 @@ DEFUN(test_withdraw_evpn_type4_route,
        }
 
        if (!bgp->peer_self) {
-               vty_out(vty, "%%BGP instance doesnt have self peer\n");
+               vty_out(vty, "%%BGP instance doesn't have self peer\n");
                return CMD_WARNING;
        }
 
index 14d692ebf0934d2eee3def8f0e1be2286876c9c8..3f9aae0054330731bdc1bb3a0e7464eafd57eca5 100644 (file)
@@ -917,7 +917,7 @@ static void bgp_update_delay_process_status_change(struct peer *peer)
        }
 }
 
-/* Called after event occured, this function change status and reset
+/* Called after event occurred, this function change status and reset
    read/write and timer thread. */
 void bgp_fsm_change_status(struct peer *peer, int status)
 {
index bb474b9e20918365101f15d0f8f0979757c2a18b..6cbb2ec06893a67a6f6bb7261aa89fbcf214df59 100644 (file)
@@ -272,7 +272,7 @@ static void bgp_update_explicit_eors(struct peer *peer)
                                           PEER_STATUS_EOR_RECEIVED)) {
                                if (bgp_debug_neighbor_events(peer))
                                        zlog_debug(
-                                               "   afi %d safi %d didnt receive EOR",
+                                               "   afi %d safi %d didn't receive EOR",
                                                afi, safi);
                                return;
                        }
index 1460a26215bbbd66b6ac2e1598e043dee0165a53..8d3a485d5b748e629048c379364fbd1f2541f973 100644 (file)
@@ -2288,7 +2288,7 @@ DEFUN (bgp_default_show_hostname,
        "bgp default show-hostname",
        "BGP specific commands\n"
        "Configure BGP defaults\n"
-       "Show hostname in certain command ouputs\n")
+       "Show hostname in certain command outputs\n")
 {
        VTY_DECLVAR_CONTEXT(bgp, bgp);
        bgp_flag_set(bgp, BGP_FLAG_SHOW_HOSTNAME);
@@ -2301,7 +2301,7 @@ DEFUN (no_bgp_default_show_hostname,
        NO_STR
        "BGP specific commands\n"
        "Configure BGP defaults\n"
-       "Show hostname in certain command ouputs\n")
+       "Show hostname in certain command outputs\n")
 {
        VTY_DECLVAR_CONTEXT(bgp, bgp);
        bgp_flag_unset(bgp, BGP_FLAG_SHOW_HOSTNAME);
@@ -5995,7 +5995,7 @@ DEFUN (neighbor_allowas_in,
        NEIGHBOR_STR
        NEIGHBOR_ADDR_STR2
        "Accept as-path with my AS present in it\n"
-       "Number of occurances of AS number\n"
+       "Number of occurrences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 {
        int idx_peer = 1;
@@ -6029,7 +6029,7 @@ ALIAS_HIDDEN(
        "neighbor <A.B.C.D|X:X::X:X|WORD> allowas-in [<(1-10)|origin>]",
        NEIGHBOR_STR NEIGHBOR_ADDR_STR2
        "Accept as-path with my AS present in it\n"
-       "Number of occurances of AS number\n"
+       "Number of occurrences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 
 DEFUN (no_neighbor_allowas_in,
@@ -6039,7 +6039,7 @@ DEFUN (no_neighbor_allowas_in,
        NEIGHBOR_STR
        NEIGHBOR_ADDR_STR2
        "allow local ASN appears in aspath attribute\n"
-       "Number of occurances of AS number\n"
+       "Number of occurrences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 {
        int idx_peer = 2;
@@ -6061,7 +6061,7 @@ ALIAS_HIDDEN(
        "no neighbor <A.B.C.D|X:X::X:X|WORD> allowas-in [<(1-10)|origin>]",
        NO_STR NEIGHBOR_STR NEIGHBOR_ADDR_STR2
        "allow local ASN appears in aspath attribute\n"
-       "Number of occurances of AS number\n"
+       "Number of occurrences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 
 DEFUN (neighbor_ttl_security,
@@ -10149,7 +10149,7 @@ static void bgp_show_peer(struct vty *vty, struct peer *p, uint8_t use_json,
                        json_object_object_add(
                                json_neigh, "gracefulRestartInfo", json_grace);
                } else {
-                       vty_out(vty, "  Graceful restart informations:\n");
+                       vty_out(vty, "  Graceful restart information:\n");
                        if (p->status == Established) {
                                vty_out(vty, "    End-of-RIB send: ");
                                FOREACH_AFI_SAFI (afi, safi) {
index 5fff6fca6651cd6014b6ca42da0b745ce1357269..f594beb078899868fe6a1f3e6f9fd36d54745ee0 100644 (file)
@@ -135,7 +135,7 @@ These following options control the daemon's VTY (interactive command line) inte
 
    NB: Unlike the other options, this option specifies a directory, not a full path.
 
-   This option is primarily used by the SNAP packaging system, its semantics may change.  It should not be neccessary in most other scenarios.
+   This option is primarily used by the SNAP packaging system, its semantics may change.  It should not be necessary in most other scenarios.
 
 MODULE LOADING
 --------------
index a8a9301588f1181eafc429cabf9c37d6f56e6fb2..cfb368bf4455ae8f588b6b12383a4a6125084025 100644 (file)
@@ -33,7 +33,7 @@ OPTIONS available for the |DAEMON| command:
 
    Set netlink receive buffer size. There are cases where zebra daemon can't handle flood of netlink messages from kernel. If you ever see "recvmsg overrun" messages in zebra log, you are in trouble.
 
-   Solution is to increase receive buffer of netlink socket. Note that kernel < 2.6.14 doesn't allow to increase it over maximum value defined in /proc/sys/net/core/rmem_max. If you want to do it, you have to increase maximum before starting zebra.
+   Solution is to increase receive buffer of netlink socket. Note that kernel < 2.6.14 doesn't allow increasing it over maximum value defined in /proc/sys/net/core/rmem_max. If you want to do it, you have to increase maximum before starting zebra.
 
    Note that this affects Linux only.
 
index 3d84c82179ecd31a95c2883b131f3b55c400c8a8..895a141e4a146c140b3fc5b45e6d047222bfccdf 100644 (file)
@@ -152,7 +152,7 @@ enum eigrp_fsm_states {
 enum eigrp_fsm_events {
        /*
         * Input event other than query from succ,
-        * FC is not satisified
+        * FC is not satisfied
         */
        EIGRP_FSM_EVENT_NQ_FCN,
 
@@ -171,7 +171,7 @@ enum eigrp_fsm_events {
        /* Query from succ while in active state */
        EIGRP_FSM_EVENT_QACT,
 
-       /* last reply, FC not satisified */
+       /* last reply, FC not satisfied */
        EIGRP_FSM_EVENT_LR_FCN,
 
        /*
index 651a9339d7ba3dd41905e9106b4e5a505e7efdd9..e4ff0c5829d612ac350b0a3902806b7d28760991 100644 (file)
@@ -228,7 +228,7 @@ void show_ip_eigrp_interface_detail(struct vty *vty, struct eigrp *eigrp,
                "Un/reliable mcasts: ", 0, "/", 0, "Un/reliable ucasts: ", 0,
                "/", 0);
        vty_out(vty, "%-2s %s %d %s %d %s %d \n", "", "Mcast exceptions: ", 0,
-               "  CR packets: ", 0, "  ACKs supressed: ", 0);
+               "  CR packets: ", 0, "  ACKs suppressed: ", 0);
        vty_out(vty, "%-2s %s %d %s %d \n", "", "Retransmissions sent: ", 0,
                "Out-of-sequence rcvd: ", 0);
        vty_out(vty, "%-2s %s %s %s \n", "", "Authentication mode is ", "not",
index eeefc519688ccce2c37f7298254b46bfa46b91be..1385d48106d881164e4311355ca1b0cc8e55c03d 100644 (file)
@@ -222,9 +222,9 @@ static const char *fsm_state2str(enum eigrp_fsm_events event)
        case EIGRP_FSM_EVENT_LR:
                return "Last Reply Event";
        case EIGRP_FSM_EVENT_Q_FCN:
-               return "Query Event Feasability not satisified";
+               return "Query Event Feasability not satisfied";
        case EIGRP_FSM_EVENT_LR_FCS:
-               return "Last Reply Event Feasability satisified";
+               return "Last Reply Event Feasability satisfied";
        case EIGRP_FSM_EVENT_DINC:
                return "Distance Increase Event";
        case EIGRP_FSM_EVENT_QACT:
index 341921146bb522858fe6bb004b3bbd439eb0090d..70786a5e58c1c7aa6638b0f3f1740c22f3f9866a 100644 (file)
@@ -1132,7 +1132,7 @@ static int isis_spf_preload_tent(struct isis_spftree *spftree,
                                case ISIS_SYSTYPE_UNKNOWN:
                                default:
                                        zlog_warn(
-                                               "isis_spf_preload_tent unknow adj type");
+                                               "isis_spf_preload_tent unknown adj type");
                                }
                        }
                        list_delete_and_null(&adj_list);
index 8eed0899000c434469be782e488cf8f3492d3688..c24e1917ccf7b974cf859caf24d01b6930d8758b 100644 (file)
@@ -156,7 +156,7 @@ DEFPY  (ldp_dual_stack_transport_connection_prefer_ipv4,
        NO_STR
        "Configure dual stack parameters\n"
        "Configure TCP transport parameters\n"
-       "Configure prefered address family for TCP transport connection with neighbor\n"
+       "Configure preferred address family for TCP transport connection with neighbor\n"
        "IPv4\n")
 {
        return (ldp_vty_trans_pref_ipv4(vty, no));
index 12f9cb0ccf94d580d5b1e259c5167be2d52564c8..b4d74f1950ec69b78ea1b7a1ec2ace93471ee69b 100644 (file)
@@ -259,7 +259,7 @@ embedscope(struct sockaddr_in6 *sin6)
        if (IN6_IS_SCOPE_EMBED(&sin6->sin6_addr)) {
                memcpy(&tmp16, &sin6->sin6_addr.s6_addr[2], sizeof(tmp16));
                if (tmp16 != 0) {
-                       log_warnx("%s: address %s already has embeded scope %u",
+                       log_warnx("%s: address %s already has embedded scope %u",
                            __func__, log_sockaddr(sin6), ntohs(tmp16));
                }
                tmp16 = htons(sin6->sin6_scope_id);
index 0eddb47514d5e5ea39d104c33650317922f07dc1..93c021839d7d309c203928e174bb93fd7c5cfa96 100644 (file)
--- a/lib/bfd.c
+++ b/lib/bfd.c
@@ -134,7 +134,7 @@ void bfd_peer_sendmsg(struct zclient *zclient, struct bfd_info *bfd_info,
        int ret;
        int len;
 
-       /* Individual reg/dereg messages are supressed during shutdown. */
+       /* Individual reg/dereg messages are suppressed during shutdown. */
        if (CHECK_FLAG(bfd_gbl.flags, BFD_GBL_FLAG_IN_SHUTDOWN)) {
                if (bfd_debug)
                        zlog_debug(
index 75b69507ec7bf153e281b3ca818dacf4ba4cf073..555225187d8b4423fc629841527d01ea66274a66 100644 (file)
@@ -354,7 +354,7 @@ struct cmd_node {
 #define IN_STR  "Filter incoming routing updates\n"
 #define V4NOTATION_STR "specify by IPv4 address notation(e.g. 0.0.0.0)\n"
 #define OSPF6_NUMBER_STR "Specify by number\n"
-#define INTERFACE_STR "Interface infomation\n"
+#define INTERFACE_STR "Interface information\n"
 #define IFNAME_STR "Interface name(e.g. ep0)\n"
 #define IP6_STR "IPv6 Information\n"
 #define OSPF6_STR "Open Shortest Path First (OSPF) for IPv6\n"
index 332a5b1d453aac833f4811dd1734a177b9f1a98c..e65ee48cfc725da586392639bf5f76e4eaa3ccb9 100644 (file)
@@ -37,8 +37,8 @@ static struct log_ref ferr_lib_err[] = {
        {
                .code = LIB_ERR_SOCKET,
                .title = "Socket Error",
-               .description = "When attempting to access a socket a system error has occured and we were unable to properly complete the request",
-               .suggestion = "Ensure that there are sufficient system resources available and ensure that the frr user has sufficient permisions to work",
+               .description = "When attempting to access a socket a system error has occurred and we were unable to properly complete the request",
+               .suggestion = "Ensure that there are sufficient system resources available and ensure that the frr user has sufficient permissions to work",
        },
        {
                .code = LIB_ERR_ZAPI_MISSMATCH,
index c9dd60dce0a87cb9384c160acae49dec7d01d2b1..61469856105fb0b35a2108172ca41672bde19412 100644 (file)
@@ -171,7 +171,7 @@ static inline char *label2str(mpls_label_t label, char *buf, size_t len)
                strlcpy(buf, "Router Alert", len);
                return (buf);
        case MPLS_LABEL_IPV6_EXPLICIT_NULL:
-               strlcpy(buf, "IPv6 Explict Null", len);
+               strlcpy(buf, "IPv6 Explicit Null", len);
                return (buf);
        case MPLS_LABEL_IMPLICIT_NULL:
                strlcpy(buf, "implicit-null", len);
index bbbfbfc424d9c37ab46eaf45eccda35217286f9c..b9b2bbf13b8679e12ae08d5234c0a2dc96d9997c 100644 (file)
@@ -351,7 +351,7 @@ int sockopt_ttl(int family, int sock, int ttl)
  * Which on linux is a no-op since it is enabled by
  * default and on BSD it uses TCP_NOPUSH to do
  * the same thing( which it was not configured to
* use).  This cleanup of the api occured on 8/1/17
  * I imagine if after more than 1 year of no-one
  * complaining, and a major upgrade release we
  * can deprecate and remove this function call
index 27b0f0c4f035338c7186790c9bdd7f69fad7e8fd..37cbe9187cd997117b985e3c27dfd45ee761477e 100644 (file)
@@ -22,7 +22,7 @@
 #   another object file.
 #
 #   There are four known schemes of declaring weak symbols; each scheme is
-#   checked in turn, and the first one found is prefered. Note that only one
+#   checked in turn, and the first one found is preferred. Note that only one
 #   of the mentioned preprocessor macros will be defined!
 #
 #   1. Function attributes
index 7bccc78e00882fe4f93daea760c176f2e4eaeaa6..bf1816fe1e192999a4a964468fe62158f44cf03e 100644 (file)
@@ -320,7 +320,7 @@ int ospf6_abr_originate_summary_to_area(struct ospf6_route *route,
 
        /* if this is a route to ASBR */
        if (route->type == OSPF6_DEST_TYPE_ROUTER) {
-               /* Only the prefered best path is considered */
+               /* Only the preferred best path is considered */
                if (!CHECK_FLAG(route->flag, OSPF6_ROUTE_BEST)) {
                        if (is_debug)
                                zlog_debug(
index 2cab69aac221e1c2a1fcb11e56f586099104e6ed..b24d2beb85d1df9ba03f69a27016812f3bd92cdc 100644 (file)
@@ -771,7 +771,7 @@ DEFUN (show_ipv6_ospf6_spf_tree,
        SHOW_STR
        IP6_STR
        OSPF6_STR
-       "Shortest Path First caculation\n"
+       "Shortest Path First calculation\n"
        "Show SPF tree\n")
 {
        struct listnode *node;
@@ -806,7 +806,7 @@ DEFUN (show_ipv6_ospf6_area_spf_tree,
        OSPF6_STR
        OSPF6_AREA_STR
        OSPF6_AREA_ID_STR
-       "Shortest Path First caculation\n"
+       "Shortest Path First calculation\n"
        "Show SPF tree\n")
 {
        int idx_ipv4 = 4;
index 06a84dcb933c478c6bcda75fd63b8d0c50eda16c..7c2ba10edcea769de31a24ab04d0207fc48e31d8 100644 (file)
@@ -266,7 +266,7 @@ DEFUN (show_zebra,
                return CMD_SUCCESS;
        }
 
-       vty_out(vty, "Zebra Infomation\n");
+       vty_out(vty, "Zebra Information\n");
        vty_out(vty, "  fail: %d\n", zclient->fail);
        vty_out(vty, "  redistribute default: %d\n",
                vrf_bitmap_check(zclient->default_information, VRF_DEFAULT));
index 25ab9cbe0fd37cfb3f6d1f865c5aedf466ec731c..c131bacb85f7b212914759c5d0a239aca952ba5e 100644 (file)
@@ -277,7 +277,7 @@ static int ospf_wait_timer(struct thread *thread)
        return 0;
 }
 
/* Hook function called after ospf ISM event is occured. And vty's
    network command invoke this function after making interface
    structure. */
 static void ism_timer_set(struct ospf_interface *oi)
index 1e72e3db6308f93ba136cf3e18222942a05f08bf..df467fb8641212066a138bbb118ff6af1b6bbfb5 100644 (file)
@@ -93,7 +93,7 @@ static int ospf_db_desc_timer(struct thread *thread)
        return 0;
 }
 
/* Hook function called after ospf NSM event is occured.
  *
  * Set/clear any timers whose condition is implicit to the neighbour
  * state. There may be other timers which are set/unset according to other
index be62eb3906d08bcdea1f5b3b7201d156bd4abfa6..243766d842be7a31f017fd353daa6410ec679135 100644 (file)
@@ -510,7 +510,7 @@ struct opaque_info_per_type {
        /* Collection of callback functions for this opaque-type. */
        struct ospf_opaque_functab *functab;
 
/* List of Opaque-LSA control informations per opaque-id. */
        struct list *id_list;
 };
 
index 56b83d22d5b7ca9f84d41f1de34959999b4737cb..bdf14d7821f0c3485b632e009be18d2dcfd861dc 100644 (file)
@@ -3321,7 +3321,7 @@ static int ospf_make_db_desc(struct ospf_interface *oi,
                                if (IS_OPAQUE_LSA(lsa->data->type)
                                    && (!CHECK_FLAG(options, OSPF_OPTION_O))) {
                                        /* Suppress advertising
-                                        * opaque-informations. */
+                                        * opaque-information. */
                                        /* Remove LSA from DB summary list. */
                                        ospf_lsdb_delete(lsdb, lsa);
                                        continue;
index c9d0a53c8dc1cf42c7504866d4fb8b2ab808508c..d4d406583a1dfa28a9b2d27d7f0c74786c22c37e 100644 (file)
@@ -598,7 +598,7 @@ static int is_mandated_params_set(struct ospf_router_info ori)
  * @param enable To activate or not Segment Routing router Information flooding
  * @param size   Size of Label Range i.e. SRGB size
  * @param lower  Lower bound of the Label Range i.e. SRGB first label
- * @param msd    Maximum label Stack Depth suported by the router
+ * @param msd    Maximum label Stack Depth supported by the router
  *
  * @return none
  */
index a9dc1c18e392e110701acbbdc991215a6bf25fd7..9743652210565b65b34d021bf765fd9658289899 100644 (file)
@@ -2399,7 +2399,7 @@ DEFUN (no_ospf_mpls_te_inter_as,
                                ospf_mpls_te_lsa_schedule(lp, FLUSH_THIS_LSA);
        }
 
-       /* Deregister the Callbacks for Inter-AS suport */
+       /* Deregister the Callbacks for Inter-AS support */
        ospf_mpls_te_unregister();
 
        return CMD_SUCCESS;
index bfaedf2fe70236495ac6906007a923df275017f2..b7dfedd15a42c5c283389a1c0bd24249aa32eb75 100644 (file)
@@ -171,7 +171,7 @@ void ospf_router_id_update(struct ospf *ospf)
 
                /* Flush (inline) all external LSAs which now match the new
                   router-id,
-                  need to adjust the OSPF_LSA_SELF flag, so the flush doesnt
+                  need to adjust the OSPF_LSA_SELF flag, so the flush doesn't
                   hit
                   asserts in ospf_refresher_unregister_lsa(). This step is
                   needed
index 25d64238bfd3b6ced06a290e6795e8bad96d93db..b7391a171a653215e09d8b23bb99485bd82a3ae4 100644 (file)
@@ -207,13 +207,13 @@ static int rule_notify_owner(int command, struct zclient *zclient,
 
        switch (note) {
        case ZAPI_RULE_FAIL_INSTALL:
-               DEBUGD(&pbr_dbg_zebra, "%s: Recieved RULE_FAIL_INSTALL",
+               DEBUGD(&pbr_dbg_zebra, "%s: Received RULE_FAIL_INSTALL",
                       __PRETTY_FUNCTION__);
                pbrms->installed &= ~installed;
                break;
        case ZAPI_RULE_INSTALLED:
                pbrms->installed |= installed;
-               DEBUGD(&pbr_dbg_zebra, "%s: Recived RULE_INSTALLED",
+               DEBUGD(&pbr_dbg_zebra, "%s: Received RULE_INSTALLED",
                       __PRETTY_FUNCTION__);
                break;
        case ZAPI_RULE_FAIL_REMOVE:
index 7fcf42e8ce3adadcd013bcd198ffbe574f558af9..8e1565e485e8bb3923113eb45c625201dea73e49 100644 (file)
@@ -74,7 +74,7 @@ static int pim_msdp_sa_adv_timer_cb(struct thread *t)
        struct pim_instance *pim = THREAD_ARG(t);
 
        if (PIM_DEBUG_MSDP_EVENTS) {
-               zlog_debug("MSDP SA advertisment timer expired");
+               zlog_debug("MSDP SA advertisement timer expired");
        }
 
        pim_msdp_sa_adv_timer_setup(pim, true /* start */);
index 15cbf6fbc331f5ac464c118063c81237e9a9e889..3803e78fdef121d92b87045a02c87befb0bad0c5 100644 (file)
@@ -464,7 +464,7 @@ static int pim_upstream_could_register(struct pim_upstream *up)
        return 0;
 }
 
-/* Source registration is supressed for SSM groups. When the SSM range changes
+/* Source registration is suppressed for SSM groups. When the SSM range changes
  * we re-revaluate register setup for existing upstream entries */
 void pim_upstream_register_reevaluate(struct pim_instance *pim)
 {
index 02ead6fde2d56a279f8249f54088206d7ecc0020..dee27e2960e255fa5856f836bdd4cf39259f076d 100644 (file)
@@ -1239,7 +1239,7 @@ static void rip_response_process(struct rip_packet *packet, int size,
                   Ciscos before the 'ip subnet zero' option, it would be almost
                   right too :-)
 
-                  Cisco summarize ripv1 advertisments to the classful boundary
+                  Cisco summarize ripv1 advertisements to the classful boundary
                   (/16 for class B's) except when the RIP packet does to inside
                   the classful network in question.  */
 
@@ -2514,7 +2514,7 @@ static void rip_update_process(int route_type)
                                                      VRF_DEFAULT);
                        if (!connected) {
                                zlog_warn(
-                                       "Neighbor %s doesnt have connected interface!",
+                                       "Neighbor %s doesn't have connected interface!",
                                        inet_ntoa(p->u.prefix4));
                                continue;
                        }
index 934a87b0751f502c2e6b8b90ea94e18842c70128..214ee7282a22af0bb46eab8121c7c14a3dbe4343 100644 (file)
@@ -1564,7 +1564,7 @@ void ripng_output_process(struct interface *ifp, struct sockaddr_in6 *to,
                    && rinfo->suppress == 0) {
                        /* If no route-map are applied, the RTE will be these
                         * following
-                        * informations.
+                        * information.
                         */
                        p = (struct prefix_ipv6 *)&rp->p;
                        rinfo->metric_out = rinfo->metric;
@@ -1709,7 +1709,7 @@ void ripng_output_process(struct interface *ifp, struct sockaddr_in6 *to,
                    && aggregate->suppress == 0) {
                        /* If no route-map are applied, the RTE will be these
                         * following
-                        * informations.
+                        * information.
                         */
                        p = (struct prefix_ipv6 *)&rp->p;
                        aggregate->metric_set = 0;
index de58e0a20e2b75756bc168828a9563872ad033da..35b02a9b773b97b2aa2d4eb561aff8bcfd59f4e2 100644 (file)
@@ -1008,7 +1008,7 @@ int main(int argc, char **argv)
        if (background) { /* ok, we need to detach this process */
                int i, fd;
                if (quietmode < 0)
-                       printf("Detatching to start %s...", startas);
+                       printf("Detaching to start %s...", startas);
                i = fork();
                if (i < 0) {
                        fatal("Unable to fork.\n");
index 39b7204e8e636ea2f7363e9cd3de6b0c520cc0cc..5d63d448932aefb0f6858bf04c514d5b715d0553 100644 (file)
@@ -59,7 +59,7 @@ void ifstat_update_sysctl(void)
        /* We free this memory at the end of this function. */
        ref = buf = XMALLOC(MTYPE_TMP, bufsiz);
 
/* Fetch interface informations into allocated buffer. */
        if (sysctl(mib, MIBSIZ, buf, &bufsiz, NULL, 0) < 0) {
                zlog_warn("sysctl error by %s", safe_strerror(errno));
                XFREE(MTYPE_TMP, ref);
@@ -108,7 +108,7 @@ void interface_list(struct zebra_ns *zns)
        /* We free this memory at the end of this function. */
        ref = buf = XMALLOC(MTYPE_TMP, bufsiz);
 
/* Fetch interface informations into allocated buffer. */
        if (sysctl(mib, MIBSIZ, buf, &bufsiz, NULL, 0) < 0) {
                zlog_warn("sysctl error by %s", safe_strerror(errno));
                return;
index c36c9589738d9637fb8dd708fd0e60d1e5287e05..d404c76ec2c46aae519ba5eefc1a462f1735ff89 100644 (file)
@@ -96,7 +96,7 @@ static void parse_irdp_packet(char *p, int len, struct interface *ifp)
 
        if (len != iplen) {
                flog_err(ZEBRA_ERR_IRDP_LEN_MISMATCH,
-                         "IRDP: RX length doesnt match IP length");
+                         "IRDP: RX length doesn't match IP length");
                return;
        }
 
@@ -107,7 +107,7 @@ static void parse_irdp_packet(char *p, int len, struct interface *ifp)
                return;
        }
 
/* XXX: RAW doesnt receive link-layer, surely? ??? */
        /* Check so we don't checksum packets longer than oure RX_BUF - (ethlen
         +
         len of IP-header) 14+20 */
index 78e25e7626a21b2f4dadda339ea9c6526ba27370..ff035fb3536226c0a415177a07766d6135f9b776 100644 (file)
@@ -469,7 +469,7 @@ int ifm_read(struct if_msghdr *ifm)
                if (ifnlen && (strncmp(ifp->name, ifname, IFNAMSIZ) != 0)) {
                        if (IS_ZEBRA_DEBUG_KERNEL)
                                zlog_debug(
-                                       "%s: ifp name %s doesnt match sdl name %s",
+                                       "%s: ifp name %s doesn't match sdl name %s",
                                        __func__, ifp->name, ifname);
                        ifp = NULL;
                }
index 4f1d5cf6d584054e8eca6af1d6c125e9a8d02431..f787d641b4428ba46b3d8e90038df53488d5c602 100644 (file)
@@ -302,7 +302,7 @@ static void vty_show_ip_route_detail(struct vty *vty, struct route_node *rn,
                                if (vrf)
                                        vty_out(vty, "(vrf %s)", vrf->name);
                                else
-                                       vty_out(vty, "(vrf UKNOWN)");
+                                       vty_out(vty, "(vrf UNKNOWN)");
                        }
 
                        if (CHECK_FLAG(nexthop->flags, NEXTHOP_FLAG_DUPLICATE))
@@ -677,7 +677,7 @@ static void vty_show_ip_route(struct vty *vty, struct route_node *rn,
                        if (vrf)
                                vty_out(vty, "(vrf %s)", vrf->name);
                        else
-                               vty_out(vty, "(vrf UKNOWN)");
+                               vty_out(vty, "(vrf UNKNOWN)");
                }
 
                if (!CHECK_FLAG(nexthop->flags, NEXTHOP_FLAG_ACTIVE))
index b0fc0a39bd85663da4bee0ee5ecf0acc88e5e75e..b6febd6d4a81db8f6828685ab92398e1ba0aeb0d 100644 (file)
@@ -1843,7 +1843,7 @@ static int zvni_gw_macip_del(struct interface *ifp, zebra_vni_t *zvni,
        /* mac entry should be present */
        mac = zvni_mac_lookup(zvni, &n->emac);
        if (!mac) {
-               zlog_warn("MAC %s doesnt exists for neigh %s on VNI %u",
+               zlog_warn("MAC %s doesn't exist for neigh %s on VNI %u",
                          prefix_mac2str(&n->emac, buf1, sizeof(buf1)),
                          ipaddr2str(ip, buf2, sizeof(buf2)), zvni->vni);
                return -1;
@@ -4078,7 +4078,7 @@ void zebra_vxlan_print_specific_rmac_l3vni(struct vty *vty, vni_t l3vni,
                if (use_json)
                        vty_out(vty, "{}\n");
                else
-                       vty_out(vty, "%% L3-VNI %u doesnt exist\n", l3vni);
+                       vty_out(vty, "%% L3-VNI %u doesn't exist\n", l3vni);
                return;
        }
 
@@ -4088,7 +4088,7 @@ void zebra_vxlan_print_specific_rmac_l3vni(struct vty *vty, vni_t l3vni,
                        vty_out(vty, "{}\n");
                else
                        vty_out(vty,
-                               "%% Requested RMAC doesnt exist in L3-VNI %u",
+                               "%% Requested RMAC doesn't exist in L3-VNI %u",
                                l3vni);
                return;
        }
@@ -351,7 +351,7 @@ int sockopt_ttl(int family, int sock, int ttl)
  * default and on BSD it uses TCP_NOPUSH to do
  * the same thing( which it was not configured to
- * use).  This cleanup of the api occured on 8/1/17
+ * use).  This cleanup of the api occurred on 8/1/17
  * I imagine if after more than 1 year of no-one
  * complaining, and a major upgrade release we
@@ -277,7 +277,7 @@ static int ospf_wait_timer(struct thread *thread)
 }
 
-/* Hook function called after ospf ISM event is occured. And vty's
+/* Hook function called after ospf ISM event is occurred. And vty's
    network command invoke this function after making interface
    structure. */
@@ -93,7 +93,7 @@ static int ospf_db_desc_timer(struct thread *thread)
 }
 
-/* Hook function called after ospf NSM event is occured.
+/* Hook function called after ospf NSM event is occurred.
  *
  * Set/clear any timers whose condition is implicit to the neighbour
@@ -510,7 +510,7 @@ struct opaque_info_per_type {
        struct ospf_opaque_functab *functab;
 
-       /* List of Opaque-LSA control informations per opaque-id. */
+       /* List of Opaque-LSA control information per opaque-id. */
        struct list *id_list;
 };
@@ -59,7 +59,7 @@ void ifstat_update_sysctl(void)
        ref = buf = XMALLOC(MTYPE_TMP, bufsiz);
 
-       /* Fetch interface informations into allocated buffer. */
+       /* Fetch interface information into allocated buffer. */
        if (sysctl(mib, MIBSIZ, buf, &bufsiz, NULL, 0) < 0) {
                zlog_warn("sysctl error by %s", safe_strerror(errno));
@@ -108,7 +108,7 @@ void interface_list(struct zebra_ns *zns)
        ref = buf = XMALLOC(MTYPE_TMP, bufsiz);
 
-       /* Fetch interface informations into allocated buffer. */
+       /* Fetch interface information into allocated buffer. */
        if (sysctl(mib, MIBSIZ, buf, &bufsiz, NULL, 0) < 0) {
                zlog_warn("sysctl error by %s", safe_strerror(errno));
@@ -107,7 +107,7 @@ static void parse_irdp_packet(char *p, int len, struct interface *ifp)
        }
 
-       /* XXX: RAW doesnt receive link-layer, surely? ??? */
+       /* XXX: RAW doesn't receive link-layer, surely? ??? */
        /* Check so we don't checksum packets longer than oure RX_BUF - (ethlen
         +